#ifndef QSAINSTALLER_H
#define QSAINSTALLER_H

#include <qwizard.h>

class IntroScreen;
class License;
class LicensePage;
class FileUnpack;
class BobBuilder;
class OptionsPage;
class FinishPage;
class Uninstaller;
class WinShell;

class QProcess;

class QSAInstaller : public QWizard
{
    Q_OBJECT
public:
    enum InstallerType {  InstallType, UninstallType };

    QSAInstaller( QWidget *parent, const char *name, InstallerType type = InstallType );
    ~QSAInstaller();

    void readLicenseText();
    void readReadmeText();
    void fillLicenseInfo( const QString &licenseFile );
    void writeLicenseFile();

public slots:
    void pageChangeInstaller( const QString &str );
    void pageChangeUninstaller( const QString &str );
    void toggleLicensePage( bool enable );
    void findDirectory();
    void findFolder();
    void readLicenseFile();
    void licenseKeyChanged( const QString &key );
    void unpackFiles();
    void unpackProgress( int i );
    void buildQSA();
    void verifyEnvironment();
    void writeFolders();
    void uninstallQSA();
    void registerUninstall();
    void runMake();
    void installPathChanged( const QString & );

    void makeRead();
    void makeDone();

private:
    IntroScreen *intro;
    License *license;
    LicensePage *licenseInfo;
    FileUnpack *unpack;
    OptionsPage *options;
    BobBuilder *build;
    FinishPage *finish;
    Uninstaller *uninstaller;

    QWidget *introPage;
    QWidget *licensePage;
    QWidget *licenseInfoPage;
    QWidget *unpackPage;
    QWidget *optionsPage;
    QWidget *buildPage;
    QWidget *finishPage;
    QWidget *uninstallerPage;

    WinShell *shell;
    QProcess *makeProcess;

    const char **pageTitles;

    int unpackProgressLimit;
    InstallerType installerType;
    QString folderPath;
};

#endif
